@@ -8,9 +8,10 @@ class Pipeline:
 
 
 def main():
-    pipe = Pipeline()
+    pipe = Pipeline(class_perspective= 1, num_words= 10000)
     pipe.ncof.print_all_methods()
     pipe.tfidf.print_all_methods()
 
 if __name__ == '__main__':
+
     main()
