@@ -9,7 +9,7 @@ class ncof_pipeline:
         self.Dot = 10
         self.Class_perspective = class_perspective
         self.Verbose = True
-        self.num_words = num_wordss
+        self.num_words = num_words
     def print_all_methods(self):
         object_methods = [method_name for method_name in dir(self) if callable(getattr(self, method_name))]
         print(object_methods)
